Welcome to ``smart-arg``'s documentation!
============================================
Contents:

.. toctree::
   :maxdepth: 2
   :glob:

   README
   advanced
   api
   CONTRIBUTING
   LICENSE


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
